@@ -112,5 +112,10 @@ API_PATH = {
     "project_payment_schedule_update":  "/projects/{project_id}/payment_schedules/{schedule_id}",
     "project_payment_schedule_delete":  "/projects/{project_id}/payment_schedules/{schedule_id}",
     "purchase_category_get":            "/purchases/categories/{id}",
-    "purchase_category_getlist":        "/purchases/categories"
+    "purchase_category_getlist":        "/purchases/categories",
+    "planning_entry_getlist":           "/planning_entries",
+    "planning_entry_get":               "/planning_entries/{id}",
+    "planning_entry_create":            "/planning_entries",
+    "planning_entry_update":            "/planning_entries/{id}",
+    "planning_entry_delete":            "/planning_entries/{id}"
 }
