@@ -2,7 +2,9 @@ import json
 from collections import namedtuple
 
 class MWRAPResponse(object):
-    """base class for all responses, created by an requestor"""
+    """
+    Base class for all responses created by a requestor
+    """
 
     def __init__(self, response):
         self._response = response
@@ -17,4 +19,5 @@ class MWRAPResponse(object):
         """
         http response object
         """
-        return self._response
\ No newline at end of file
+        return self._response
+        
\ No newline at end of file
